@@ -77,13 +77,23 @@ def load(lib, IM_VERSION):
             c_void_p, c_int, c_double, c_double
         ]
         lib.MagickAdaptiveSharpenImageChannel.restype = c_bool
-    lib.MagickAdaptiveThresholdImage.argtypes = [
-        c_void_p, c_size_t, c_size_t, c_ssize_t
-    ]
-    lib.MagickAdaptiveThresholdImage.restype = c_bool
+    if is_im_6:
+        lib.MagickAdaptiveThresholdImage.argtypes = [
+            c_void_p, c_size_t, c_size_t, c_ssize_t
+        ]
+        lib.MagickAdaptiveThresholdImage.restype = c_bool
+    else:
+        lib.MagickAdaptiveThresholdImage.argtypes = [
+            c_void_p, c_size_t, c_size_t, c_double
+        ]
+        lib.MagickAdaptiveThresholdImage.restype = c_bool
     lib.MagickAddImage.argtypes = [c_void_p, c_void_p]
-    lib.MagickAddNoiseImage.argtypes = [c_void_p, c_int]
-    lib.MagickAddNoiseImage.restype = c_bool
+    if is_im_6:
+        lib.MagickAddNoiseImage.argtypes = [c_void_p, c_int]
+        lib.MagickAddNoiseImage.restype = c_bool
+    else:
+        lib.MagickAddNoiseImage.argtypes = [c_void_p, c_int, c_double]
+        lib.MagickAddNoiseImage.restype = c_bool
     if is_im_6:
         lib.MagickAddNoiseImageChannel.argtypes = [c_void_p, c_int, c_int]
         lib.MagickAddNoiseImageChannel.restype = c_bool
@@ -366,8 +376,20 @@ def load(lib, IM_VERSION):
     if is_im_6:
         lib.MagickGetImageChannelDepth.argtypes = [c_void_p, c_int]
         lib.MagickGetImageChannelDepth.restype = c_size_t
-        lib.MagickGetImageChannelFeatures.argtypes = [c_void_p]
+        lib.MagickGetImageChannelFeatures.argtypes = [c_void_p, c_size_t]
         lib.MagickGetImageChannelFeatures.restype = c_void_p
+        lib.MagickGetImageChannelKurtosis.argtypes = [
+            c_void_p, c_int, POINTER(c_double), POINTER(c_double)
+        ]
+        lib.MagickGetImageChannelKurtosis.restype = c_bool
+        lib.MagickGetImageChannelMean.argtypes = [
+            c_void_p, c_int, POINTER(c_double), POINTER(c_double)
+        ]
+        lib.MagickGetImageChannelMean.restype = c_bool
+        lib.MagickGetImageChannelRange.argtypes = [
+            c_void_p, c_int, POINTER(c_double), POINTER(c_double)
+        ]
+        lib.MagickGetImageChannelRange.restype = c_bool
         lib.MagickGetImageChannelStatistics.argtypes = [c_void_p]
         lib.MagickGetImageChannelStatistics.restype = c_void_p
         lib.MagickGetImageClipMask.argtypes = [c_void_p]
@@ -401,6 +423,9 @@ def load(lib, IM_VERSION):
         c_void_p, c_void_p, c_int, POINTER(c_double)
     ]
     lib.MagickGetImageDistortion.restype = c_bool
+    if is_im_7:
+        lib.MagickGetImageFeatures.argtypes = [c_void_p, c_size_t]
+        lib.MagickGetImageFeatures.restype = c_void_p
     lib.MagickGetImageFilename.argtypes = [c_void_p]
     lib.MagickGetImageFilename.restype = c_magick_char_p
     lib.MagickGetImageFormat.argtypes = [c_void_p]
@@ -430,10 +455,20 @@ def load(lib, IM_VERSION):
     lib.MagickGetImageIterations.restype = c_size_t
     lib.MagickGetImageInterpolateMethod.argtypes = [c_void_p]
     lib.MagickGetImageInterpolateMethod.restype = c_int
+    if is_im_7:
+        lib.MagickGetImageKurtosis.argtypes = [
+            c_void_p, POINTER(c_double), POINTER(c_double)
+        ]
+        lib.MagickGetImageKurtosis.restype = c_bool
     lib.MagickGetImageLength.argtypes = [c_void_p, POINTER(c_size_t)]
     lib.MagickGetImageLength.restype = c_bool
     lib.MagickGetImageMatteColor.argtypes = [c_void_p, c_void_p]
     lib.MagickGetImageMatteColor.restype = c_bool
+    if is_im_7:
+        lib.MagickGetImageMean.argtypes = [
+            c_void_p, POINTER(c_double), POINTER(c_double)
+        ]
+        lib.MagickGetImageMean.restype = c_bool
     lib.MagickGetImageOrientation.argtypes = [c_void_p]
     lib.MagickGetImageOrientation.restype = c_int
     lib.MagickGetImagePage.argtypes = [
@@ -899,16 +934,25 @@ def load(lib, IM_VERSION):
         lib.MagickSolarizeImageChannel.restype = c_bool
     except AttributeError:
         lib.MagickSolarizeImageChannel = None
-    lib.MagickSparseColorImage.argtypes = [
-        c_void_p, c_int, c_int, c_size_t, POINTER(c_double)
-    ]
+    if is_im_6:
+        lib.MagickSparseColorImage.argtypes = [
+            c_void_p, c_int, c_int, c_size_t, POINTER(c_double)
+        ]
+    else:
+        lib.MagickSparseColorImage.argtypes = [
+            c_void_p, c_int, c_size_t, POINTER(c_double)
+        ]
     lib.MagickSparseColorImage.restype = c_bool
     lib.MagickSpliceImage.argtypes = [
         c_void_p, c_size_t, c_size_t, c_ssize_t, c_ssize_t
     ]
     lib.MagickSpliceImage.restype = c_bool
-    lib.MagickSpreadImage.argtypes = [c_void_p, c_double]
-    lib.MagickSpreadImage.restype = c_bool
+    if is_im_6:
+        lib.MagickSpreadImage.argtypes = [c_void_p, c_double]
+        lib.MagickSpreadImage.restype = c_bool
+    else:
+        lib.MagickSpreadImage.argtypes = [c_void_p, c_int, c_double]
+        lib.MagickSpreadImage.restype = c_bool
     lib.MagickStatisticImage.argtypes = [c_void_p, c_int, c_size_t, c_size_t]
     lib.MagickStatisticImage.restype = c_bool
     if is_im_6:
